@@ -1431,7 +1431,7 @@ def log_cmd(path, mode='a'):
             # but here we're specifically looking at command line args. Without
             # this, I got some undesirable behavior when writing a script that
             # called another: the new command was overwriting the old log file.
-            if __name__ == '__main__':
+            if func.__module__ == '__main__':
                 fn_locals = bound_args(func, args, kwargs, True)
                 res = 'python'
                 for arg in sys.argv:
